@@ -1,25 +1,27 @@
-'''
+"""
 Date: 2022.02.06 16:43
 Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.06 16:43
-'''
+"""
 import os
 import time
 
 from project_scaffold.notes import TEMPLATE_ARTICLE_CONTENT, TEMPLATE_ARTICLE_STATIC
 
-_separator = '---\n'
+_separator = "---\n"
 
-_template_creator = '''\
+_template_creator = """\
 date: {date}
 author: "Rustle Karl"
-'''.format(date=time.strftime('%Y-%m-%dT%H:%M:%S+08:00'))
+""".format(
+    date=time.strftime("%Y-%m-%dT%H:%M:%S+08:00")
+)
 
-_template_article_dynamic = '''\
+_template_article_dynamic = """\
 title: "{title}"
 url:  "{url}"  # 永久链接
-'''
+"""
 
 
 def new_article(path):
@@ -35,10 +37,14 @@ def new_article(path):
 
     uri = os.path.splitext(path)[0]
     title = os.path.basename(uri)
-    url = '/'.join(['posts', prefix, uri])
+    url = "/".join(["posts", prefix, uri])
 
-    template_article = (_separator + _template_creator + '\n' +
-                        _template_article_dynamic.format(title=title, url=url))
+    template_article = (
+        _separator
+        + _template_creator
+        + "\n"
+        + _template_article_dynamic.format(title=title, url=url)
+    )
 
     if os.path.isfile(TEMPLATE_ARTICLE_STATIC.file):
         with open(TEMPLATE_ARTICLE_STATIC.file) as fp:
@@ -48,15 +54,15 @@ def new_article(path):
             else:
                 template_article += TEMPLATE_ARTICLE_STATIC.content
 
-    template_article += _separator + '\n'
+    template_article += _separator + "\n"
 
     if os.path.isfile(TEMPLATE_ARTICLE_CONTENT.file):
         with open(TEMPLATE_ARTICLE_CONTENT.file) as fp:
             content = fp.read()
             if content:
-                template_article += content
+                template_article += (content + "\n\n") * 5
             else:
-                template_article += TEMPLATE_ARTICLE_CONTENT.content
+                template_article += (TEMPLATE_ARTICLE_CONTENT.content + "\n\n") * 5
 
-    with open(path, 'w', encoding='utf-8', newline='\n') as fp:
+    with open(path, "w", encoding="utf-8", newline="\n") as fp:
         fp.write(template_article)
